# ussd_airflow

[![Gitter](https://badges.gitter.im/django_ussd_airflow/Lobby.svg)](https://gitter.im/django_ussd_airflow/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

[![CircleCI](https://circleci.com/gh/mwaaas/ussd_airflow.svg?style=svg)](https://circleci.com/gh/mwaaas/ussd_airflow)

[![codecov](https://codecov.io/gh/mwaaas/ussd_airflow/branch/master/graph/badge.svg)](https://codecov.io/gh/mwaaas/ussd_airflow)


[![Codacy Badge](https://api.codacy.com/project/badge/Grade/231ad345da874835a7c3d8e2bb401864)](https://www.codacy.com/app/francismwangi152/ussd_airflow?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=mwaaas/ussd_airflow&amp;utm_campaign=Badge_Grade)

[![Codacy Badge](https://api.codacy.com/project/badge/Coverage/231ad345da874835a7c3d8e2bb401864)](https://www.codacy.com/app/francismwangi152/ussd_airflow?utm_source=github.com&utm_medium=referral&utm_content=mwaaas/ussd_airflow&utm_campaign=Badge_Coverage)


For more information
here is the documentation 
http://django-ussd-airflow.readthedocs.io/